@@ -1,6 +1,6 @@
 package Module::Build::Tiny;
 {
-  $Module::Build::Tiny::VERSION = '0.011';
+  $Module::Build::Tiny::VERSION = '0.012';
 }
 use strict;
 use warnings;
@@ -10,18 +10,31 @@ our @EXPORT = qw/Build Build_PL/;
 use CPAN::Meta;
 use ExtUtils::BuildRC 0.003 qw/read_config/;
 use ExtUtils::Config 0.003;
-use ExtUtils::Helpers 0.010 qw/make_executable split_like_shell build_script manify man1_pagename man3_pagename/;
+use ExtUtils::Helpers 0.010 qw/make_executable split_like_shell man1_pagename man3_pagename/;
 use ExtUtils::Install qw/pm_to_blib install/;
 use ExtUtils::InstallPaths 0.002;
+use File::Basename qw/dirname/;
 use File::Find::Rule qw/find/;
+use File::Path qw/mkpath/;
 use File::Slurp qw/read_file write_file/;
 use File::Spec::Functions qw/catfile catdir rel2abs/;
 use Getopt::Long qw/GetOptions/;
 use JSON 2 qw/encode_json decode_json/;
 use TAP::Harness;
 
-my ($metafile) = grep { -e $_ } qw/META.json META.yml/ or die "No META information provided\n";
-my $meta = CPAN::Meta->load_file($metafile);
+sub _get_meta {
+	my ($metafile) = grep { -e $_ } qw/META.json META.yml/ or die "No META information provided\n";
+	return CPAN::Meta->load_file($metafile);
+}
+
+sub _manify {
+	my ($input_file, $output_file, $section, $opts) = @_;
+	my $dirname = dirname($output_file);
+	mkpath($dirname, $opts->{verbose}) if not -d $dirname;
+	Pod::Man->new(section => $section)->parse_from_file($input_file, $output_file);
+	print "Manifying $output_file\n" if $opts->{verbose} && $opts->{verbose} > 0;
+	return;
+}
 
 my %actions = (
 	build => sub {
@@ -32,9 +45,9 @@ my %actions = (
 		pm_to_blib({ %modules, %scripts }, catdir(qw/blib lib auto/));
 		make_executable($_) for values %scripts;
 
-		if ($opt{config}->exists('installman3dir')) {
-			manify($_, catfile('blib', 'bindoc', man1_pagename($_)), 1, \%opt) for keys %scripts;
-			manify($_, catfile('blib', 'libdoc', man3_pagename($_)), 3, \%opt) for keys %modules;
+		if ($opt{install_paths}->is_default_installable('libdoc')) {
+			_manify($_, catfile('blib', 'bindoc', man1_pagename($_)), 1, \%opt) for keys %scripts;
+			_manify($_, catfile('blib', 'libdoc', man3_pagename($_)), 3, \%opt) for keys %modules;
 		}
 	},
 	test => sub {
@@ -46,8 +59,7 @@ my %actions = (
 	install => sub {
 		my %opt = @_;
 		die "Must run `./Build build` first\n" if not -d 'blib';
-		my $paths = ExtUtils::InstallPaths->new(%opt, dist_name => $meta->name);
-		install($paths->install_map, @opt{qw/verbose dry_run uninst/});
+		install($opt{install_paths}->install_map, @opt{qw/verbose dry_run uninst/});
 	},
 );
 
@@ -59,21 +71,24 @@ sub Build {
 	my @env = defined $ENV{PERL_MB_OPT} ? split_like_shell($ENV{PERL_MB_OPT}) : ();
 	unshift @ARGV, map { @{$_} } grep { defined } $rc_opts->{'*'}, $bpl, $rc_opts->{$action}, \@env;
 	GetOptions(\my %opt, qw/install_base=s install_path=s% installdirs=s destdir=s prefix=s config=s% uninst:1 verbose:1 dry_run:1/);
-	$opt{config} = ExtUtils::Config->new($opt{config});
-	$actions{$action}->(%opt);
+	@opt{'config', 'meta'} = (ExtUtils::Config->new($opt{config}), _get_meta());
+	$actions{$action}->(%opt, install_paths => ExtUtils::InstallPaths->new(%opt, dist_name => $opt{meta}->name));
 }
 
 sub Build_PL {
+	my $meta = _get_meta();
 	printf "Creating new 'Build' script for '%s' version '%s'\n", $meta->name, $meta->version;
 	my $dir = $meta->name eq 'Module-Build-Tiny' ? 'lib' : 'inc';
-	write_file(build_script(), "#!perl\nuse lib '$dir';\nuse Module::Build::Tiny;\nBuild();\n");
-	make_executable(build_script());
+	write_file('Build', "#!perl\nuse lib '$dir';\nuse Module::Build::Tiny;\nBuild();\n");
+	make_executable('Build');
 	write_file(qw/_build_params/, encode_json(\@ARGV));
 	write_file("MY$_", read_file($_)) for grep { -f } qw/META.json META.yml/;
 }
 
 1;
 
+#ABSTRACT: A tiny replacement for Module::Build
+
 
 
 =pod
@@ -84,7 +99,7 @@ Module::Build::Tiny - A tiny replacement for Module::Build
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 SYNOPSIS
 
@@ -179,19 +194,6 @@ environment variable the same way they can with Module::Build.
 
 L<Module::Build>
 
-=head1 AUTHOR
-
-  David Golden <dagolden@cpan.org>
-  Leon Timmermans <leont@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-Copyright (C) 2009 - 2011 by David A. Golden, Leon Timmermans
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.10.0 or,
-at your option, any later version of Perl 5 you may have available.
-
 =for Pod::Coverage Build_PL
 =end
 
@@ -211,7 +213,7 @@ David Golden <dagolden@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Leon Timmermans.
+This software is copyright (c) 2011 by Leon Timmermans, David Golden.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
@@ -221,8 +223,5 @@ the same terms as the Perl 5 programming language system itself.
 
 __END__
 
-#ABSTRACT: A tiny replacement for Module::Build
-
-
 
 # vi:et:sts=2:sw=2:ts=2
